<?php

/**
 * XML-RPC check on Flatnuke version - Server
 *
 * This code builds the XML-RPC server that clients can
 * call to know (almost) everything about the version
 * they are using, even getting some useful hints on
 * actions to perform.
 *
 * @author Marco Segato <segatom@users.sourceforge.net>
 * @version 20080121
 * @license http://opensource.org/licenses/gpl-license.php GNU General Public License
 */


// include Flatnuke APIs and XML-RPC protocol
include_once("shared.php");
include_once("include/xmlrpc/IXR.php");

// build XML-RPC server
$server = new IXR_Server(array(
    'flatnuke.getFnVersion' => 'getFnVersion'
));


/**
 * Returns informations about the Flatnuke version in use
 *
 * This function can tell you if the Flatnuke version in use
 * is the last one or not, and can even specify if you should
 * urgently upgrade due to security problems.
 *
 * List of return codes:
 *  [NULL]    = Error, no version specified by the client
 *  [UNKNOWN] = The client is using an unknown version
 *  [WARNING] = The client is using an old and *bugged* version
 *  [OLD]     = The client is using an old version
 *  [CURRENT] = The client is using the latest official version
 *  [DEVEL]   = The client is using a beta version
 *
 * @author Marco Segato <segatom@users.sourceforge.net>
 *
 * @param  string $version Version to check
 * @return string $code    Return code
 */
function getFnVersion($version) {
	// sanitize input data
	$version  = getparam($version, PAR_NULL, SAN_FLAT);
	
	// get XML archive with the list of all Flatnuke versions
	$xml_versions = get_file("fn_chkversion_list.xml");
	// current version
	$current  = get_xml_element("current", $xml_versions);
	// list of official versions
	$official  = get_xml_element("officials", $xml_versions);
	$officials = get_xml_array("version", $official);
	// list of warning versions
	$warning  = get_xml_element("warnings", $xml_versions);
	$warnings = get_xml_array("version", $warning);
	
	// request error
	if ($version == "")
		return "NULL";
	// official version
	if (in_array($version, $officials)) {
		if (in_array($version, $warnings))
			return "WARNING";
		if ($version < $current)
			return "OLD";
		if ($version == $current)
			return "CURRENT";
	}
	// developing version
	if ($version > $current) {
		return "DEVEL";
	} else return "UNKNOWN";
}

?>
